==> nativescript-ui-listview-6.4.1.tgz: package/README.md <==
# NativeScript UI ListView

- [Overview](#overview)
- [Installation](#installation)
- [Documentation](#documentation)
- [API Reference](#api-reference)
- [Sample Apps](#sample-apps)
- [Release Notes](#release-notes)
- [Get Help](#get-help)


## Overview

**NativeScript UI ListView** is part of [Progress NativeScript UI](https://www.nativescript.org/ui-for-nativescript) - a suite of rich-UI components targeting the NativeScript platform.

The **NativeScript UI ListView** plugin is a virtualizing list component that provides the most popular features associated with scenarios where a list of items is used. All these features are embedded in one control with the idea to save developer time and provide better experience. The main features include:

* Item animations
* Different layouts and orientations
* Smart defaults for many gestures - select on long press, execution of special action on swipe, reorder of items on long press and drag, refreshing the list on swipe or loading more items only when needed.

<img src="https://docs.nativescript.org/img/ui-for-nativescript/listview-ios.png"><img src="https://docs.nativescript.org/img/ui-for-nativescript/listview-android.png">

## Installation

In Command prompt / Terminal navigate to your application root folder and run:

```
tns plugin add nativescript-ui-listview
```

## Documentation

More information is available in the Guides for:
- [NativeScript Core](https://docs.nativescript.org/ui/professional-ui-components/ListView/overview)
- [NativeScript with Angular](https://docs.nativescript.org/angular/ui/professional-ui-components/ng-ListView/overview)
- [NativeScript with Vue.js](https://docs.nativescript.org/vuejs/ns-ui/ListView/overview)

## API Reference

[Here](https://docs.nativescript.org/ns-ui-api-reference/classes/radlistview) is the API Reference section.

## Sample Apps

The features of the plugin are demonstrated in the Sample apps for:
- [NativeScript Core](https://github.com/NativeScript/nativescript-ui-samples)
- [NativeScript with Angular](https://github.com/NativeScript/nativescript-ui-samples-angular)
- [NativeScript with Vue.js](https://github.com/NativeScript/nativescript-ui-samples-vue)

## Release Notes

The release notes are available [here](https://github.com/NativeScript/nativescript-ui-feedback/blob/master/releases/listview.md).

## Get Help

Please, use [github issues](https://github.com/NativeScript/nativescript-ui-feedback/issues) strictly for reporting bugs or requesting features.

==> nativescript-ui-listview-10.2.7.tgz: package/README.md <==
# NativeScript UI ListView

- [Overview](#overview)
- [Installation](#installation)
- [Documentation](#documentation)
- [API Reference](#api-reference)
- [Sample Apps](#sample-apps)
- [Release Notes](#release-notes)
- [Get Help](#get-help)


## Overview

The **NativeScript UI ListView** plugin is a virtualizing list component that provides the most popular features associated with scenarios where a list of items is used. All these features are embedded in one control with the idea to save developer time and provide better experience. The main features include:

* Item animations
* Different layouts and orientations
* Smart defaults for many gestures - select on long press, execution of special action on swipe, reorder of items on long press and drag, refreshing the list on swipe or loading more items only when needed.

## Installation

In Command prompt / Terminal navigate to your application root folder and run:

```
tns plugin add nativescript-ui-listview
```

## Documentation

More information is available in the Guides for:
- [NativeScript Core](https://docs.nativescript.org/ui/professional-ui-components/ListView/overview)
- [NativeScript with Angular](https://docs.nativescript.org/angular/ui/ng-components/ng-RadListView/overview)
- [NativeScript with Vue.js](https://docs.nativescript.org/vuejs/ns-ui/ListView/overview)

## API Reference

[Here](https://docs.nativescript.org/ns-ui-api-reference/classes/radlistview) is the API Reference section.

## Sample Apps

The features of the plugin are demonstrated in the Sample apps for:
- [NativeScript Core](https://github.com/NativeScript/nativescript-ui-samples)
- [NativeScript with Angular](https://github.com/NativeScript/nativescript-ui-samples-angular)
- [NativeScript with Vue.js](https://github.com/NativeScript/nativescript-ui-samples-vue)

## Release Notes

The release notes are available [here](https://github.com/NativeScript/nativescript-ui-feedback/blob/master/releases/listview.md).

## Get Help

Please, use [github issues](https://github.com/NativeScript/nativescript-ui-feedback/issues) strictly for reporting bugs or requesting features.
